graph.treatment <- function(list.of.res, n.datasets){
  fx <- list.of.res$res
  
  coefs <- sapply(fx, function(x) x[[1]][2])
  ses <- sapply(fx, function(x) x[[2]][2])
  mins <- coefs - 1.96 * ses
  maxs <- coefs + 1.96 * ses
  inrange <- mins <= list.of.res$ate & maxs >= list.of.res$ate
  
  par(mfrow = c(1,2))
  hist(coefs,
       xlab = paste0("Estimated Treatment Effect\n(True treatment effect: ",
                     list.of.res$ate,
                     ")"),
       main = paste0("ATE from our ", n.datasets, " independent datasets"))
  abline(v = list.of.res$ate,
         col = "blue")
  
  
  plot(0,
       xlim = c(min(c(min(mins), list.of.res$ate)),
                max(c(max(maxs), list.of.res$ate))),
       ylim = c(1,n.datasets),
       col = "white",
       ylab = "",
       main = "Confidence Interval around ATE for each Dataset",
       xlab = paste0("Estimated Treatment Effect\n(True treatment effect: ",
                     list.of.res$ate,
                     ")"))
  segments(x0 = mins[inrange],
           x1 = maxs[inrange],
           y0 = c(1:n.datasets)[inrange],
           y1 = c(1:n.datasets)[inrange],
           lwd = .5,
           col = "black")
  segments(x0 = mins[!inrange],
           x1 = maxs[!inrange],
           y0 = c(1:n.datasets)[!inrange],
           y1 = c(1:n.datasets)[!inrange],
           lwd = .5,
           col = "red")
  abline(v = list.of.res$ate,
         col = "blue")
}





graph.dag <- function(x2.to.x1 = F){
  if(x2.to.x1){
    edges <- graph.data.frame(data.frame(from = c("X1","X1","X2","X4","D","D","Y","X2"),
                                         to = c("D","Y","Y","D","Y","X3","X3","U1")),
                              directed = T)
  } else{
    edges <- graph.data.frame(data.frame(from = c("X1","X1","X2","X4","D","D","Y"),
                                         to = c("D","Y","Y","D","Y","X3","X3")),
                              directed = T)
  }
  plot(edges,
       edge.arrow.size = 1,
       vertex.color = "white",
       vertex.label.color = "black",
       edge.color = "black",
       layout = layout_in_circle(edges, order = V(edges)[c(6,2,1,3,4,5)]),
       vertex.label.cex=3,
       vertex.frame.color=NA)
}